==> google-cloud-bigquery-data-exchange-0.1.1.tar.gz: google-cloud-bigquery-data-exchange-0.1.1/google/cloud/bigquery_data_exchange_v1beta1/services/analytics_hub_service/transports/base.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import abc
from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
import pkg_resources

import google.auth  # type: ignore
import google.api_core
from google.api_core import exceptions as core_exceptions
from google.api_core import gapic_v1
from google.api_core import retry as retries
from google.auth import credentials as ga_credentials  # type: ignore
from google.oauth2 import service_account  # type: ignore

from google.cloud.bigquery_data_exchange_v1beta1.types import dataexchange
from google.iam.v1 import iam_policy_pb2  # type: ignore
from google.iam.v1 import policy_pb2  # type: ignore
from google.protobuf import empty_pb2  # type: ignore

try:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
        gapic_version=pkg_resources.get_distribution(
            "google-cloud-bigquery-data-exchange",
        ).version,
    )
except pkg_resources.DistributionNotFound:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()


class AnalyticsHubServiceTransport(abc.ABC):
    """Abstract transport class for AnalyticsHubService."""

    AUTH_SCOPES = (
        "https://www.googleapis.com/auth/bigquery",
        "https://www.googleapis.com/auth/cloud-platform",
    )

    DEFAULT_HOST: str = "analyticshub.googleapis.com"

    def __init__(
        self,
        *,
        host: str = DEFAULT_HOST,
        credentials: ga_credentials.Credentials = None,
        credentials_file: Optional[str] = None,
        scopes: Optional[Sequence[str]] = None,
        quota_project_id: Optional[str] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
        always_use_jwt_access: Optional[bool] = False,
        **kwargs,
    ) -> None:
        """Instantiate the transport.

        Args:
            host (Optional[str]):
                 The hostname to connect to.
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is mutually exclusive with credentials.
            scopes (Optional[Sequence[str]]): A list of scopes.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                be used for service account credentials.
        """

        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
        if ":" not in host:
            host += ":443"
        self._host = host

        scopes_kwargs = {"scopes": scopes, "default_scopes": self.AUTH_SCOPES}

        # Save the scopes.
        self._scopes = scopes

        # If no credentials are provided, then determine the appropriate
        # defaults.
        if credentials and credentials_file:
            raise core_exceptions.DuplicateCredentialArgs(
                "'credentials_file' and 'credentials' are mutually exclusive"
            )

        if credentials_file is not None:
            credentials, _ = google.auth.load_credentials_from_file(
                credentials_file, **scopes_kwargs, quota_project_id=quota_project_id
            )
        elif credentials is None:
            credentials, _ = google.auth.default(
                **scopes_kwargs, quota_project_id=quota_project_id
            )

        # If the credentials are service account credentials, then always try to use self signed JWT.
        if (
            always_use_jwt_access
            and isinstance(credentials, service_account.Credentials)
            and hasattr(service_account.Credentials, "with_always_use_jwt_access")
        ):
            credentials = credentials.with_always_use_jwt_access(True)

        # Save the credentials.
        self._credentials = credentials

    def _prep_wrapped_messages(self, client_info):
        # Precompute the wrapped methods.
        self._wrapped_methods = {
            self.list_data_exchanges: gapic_v1.method.wrap_method(
                self.list_data_exchanges,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_org_data_exchanges: gapic_v1.method.wrap_method(
                self.list_org_data_exchanges,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_data_exchange: gapic_v1.method.wrap_method(
                self.get_data_exchange,
                default_timeout=None,
                client_info=client_info,
            ),
            self.create_data_exchange: gapic_v1.method.wrap_method(
                self.create_data_exchange,
                default_timeout=None,
                client_info=client_info,
            ),
            self.update_data_exchange: gapic_v1.method.wrap_method(
                self.update_data_exchange,
                default_timeout=None,
                client_info=client_info,
            ),
            self.delete_data_exchange: gapic_v1.method.wrap_method(
                self.delete_data_exchange,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_listings: gapic_v1.method.wrap_method(
                self.list_listings,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_listing: gapic_v1.method.wrap_method(
                self.get_listing,
                default_timeout=None,
                client_info=client_info,
            ),
            self.create_listing: gapic_v1.method.wrap_method(
                self.create_listing,
                default_timeout=None,
                client_info=client_info,
            ),
            self.update_listing: gapic_v1.method.wrap_method(
                self.update_listing,
                default_timeout=None,
                client_info=client_info,
            ),
            self.delete_listing: gapic_v1.method.wrap_method(
                self.delete_listing,
                default_timeout=None,
                client_info=client_info,
            ),
            self.subscribe_listing: gapic_v1.method.wrap_method(
                self.subscribe_listing,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_iam_policy: gapic_v1.method.wrap_method(
                self.get_iam_policy,
                default_timeout=None,
                client_info=client_info,
            ),
            self.set_iam_policy: gapic_v1.method.wrap_method(
                self.set_iam_policy,
                default_timeout=None,
                client_info=client_info,
            ),
            self.test_iam_permissions: gapic_v1.method.wrap_method(
                self.test_iam_permissions,
                default_timeout=None,
                client_info=client_info,
            ),
        }

    def close(self):
        """Closes resources associated with the transport.

        .. warning::
             Only call this method if the transport is NOT shared
             with other clients - this may cause errors in other clients!
        """
        raise NotImplementedError()

    @property
    def list_data_exchanges(
        self,
    ) -> Callable[
        [dataexchange.ListDataExchangesRequest],
        Union[
            dataexchange.ListDataExchangesResponse,
            Awaitable[dataexchange.ListDataExchangesResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def list_org_data_exchanges(
        self,
    ) -> Callable[
        [dataexchange.ListOrgDataExchangesRequest],
        Union[
            dataexchange.ListOrgDataExchangesResponse,
            Awaitable[dataexchange.ListOrgDataExchangesResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_data_exchange(
        self,
    ) -> Callable[
        [dataexchange.GetDataExchangeRequest],
        Union[dataexchange.DataExchange, Awaitable[dataexchange.DataExchange]],
    ]:
        raise NotImplementedError()

    @property
    def create_data_exchange(
        self,
    ) -> Callable[
        [dataexchange.CreateDataExchangeRequest],
        Union[dataexchange.DataExchange, Awaitable[dataexchange.DataExchange]],
    ]:
        raise NotImplementedError()

    @property
    def update_data_exchange(
        self,
    ) -> Callable[
        [dataexchange.UpdateDataExchangeRequest],
        Union[dataexchange.DataExchange, Awaitable[dataexchange.DataExchange]],
    ]:
        raise NotImplementedError()

    @property
    def delete_data_exchange(
        self,
    ) -> Callable[
        [dataexchange.DeleteDataExchangeRequest],
        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
    ]:
        raise NotImplementedError()

    @property
    def list_listings(
        self,
    ) -> Callable[
        [dataexchange.ListListingsRequest],
        Union[
            dataexchange.ListListingsResponse,
            Awaitable[dataexchange.ListListingsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_listing(
        self,
    ) -> Callable[
        [dataexchange.GetListingRequest],
        Union[dataexchange.Listing, Awaitable[dataexchange.Listing]],
    ]:
        raise NotImplementedError()

    @property
    def create_listing(
        self,
    ) -> Callable[
        [dataexchange.CreateListingRequest],
        Union[dataexchange.Listing, Awaitable[dataexchange.Listing]],
    ]:
        raise NotImplementedError()

    @property
    def update_listing(
        self,
    ) -> Callable[
        [dataexchange.UpdateListingRequest],
        Union[dataexchange.Listing, Awaitable[dataexchange.Listing]],
    ]:
        raise NotImplementedError()

    @property
    def delete_listing(
        self,
    ) -> Callable[
        [dataexchange.DeleteListingRequest],
        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
    ]:
        raise NotImplementedError()

    @property
    def subscribe_listing(
        self,
    ) -> Callable[
        [dataexchange.SubscribeListingRequest],
        Union[
            dataexchange.SubscribeListingResponse,
            Awaitable[dataexchange.SubscribeListingResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_iam_policy(
        self,
    ) -> Callable[
        [iam_policy_pb2.GetIamPolicyRequest],
        Union[policy_pb2.Policy, Awaitable[policy_pb2.Policy]],
    ]:
        raise NotImplementedError()

    @property
    def set_iam_policy(
        self,
    ) -> Callable[
        [iam_policy_pb2.SetIamPolicyRequest],
        Union[policy_pb2.Policy, Awaitable[policy_pb2.Policy]],
    ]:
        raise NotImplementedError()

    @property
    def test_iam_permissions(
        self,
    ) -> Callable[
        [iam_policy_pb2.TestIamPermissionsRequest],
        Union[
            iam_policy_pb2.TestIamPermissionsResponse,
            Awaitable[iam_policy_pb2.TestIamPermissionsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def kind(self) -> str:
        raise NotImplementedError()


__all__ = ("AnalyticsHubServiceTransport",)

==> google-cloud-bigquery-data-exchange-0.3.2.tar.gz: google-cloud-bigquery-data-exchange-0.3.2/google/cloud/bigquery_data_exchange_v1beta1/services/analytics_hub_service/transports/base.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import abc
from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
import pkg_resources

import google.auth  # type: ignore
import google.api_core
from google.api_core import exceptions as core_exceptions
from google.api_core import gapic_v1
from google.api_core import retry as retries
from google.auth import credentials as ga_credentials  # type: ignore
from google.oauth2 import service_account  # type: ignore

from google.cloud.bigquery_data_exchange_v1beta1.types import dataexchange
from google.cloud.location import locations_pb2  # type: ignore
from google.iam.v1 import iam_policy_pb2  # type: ignore
from google.iam.v1 import policy_pb2  # type: ignore
from google.protobuf import empty_pb2  # type: ignore

try:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
        gapic_version=pkg_resources.get_distribution(
            "google-cloud-bigquery-data-exchange",
        ).version,
    )
except pkg_resources.DistributionNotFound:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()


class AnalyticsHubServiceTransport(abc.ABC):
    """Abstract transport class for AnalyticsHubService."""

    AUTH_SCOPES = (
        "https://www.googleapis.com/auth/bigquery",
        "https://www.googleapis.com/auth/cloud-platform",
    )

    DEFAULT_HOST: str = "analyticshub.googleapis.com"

    def __init__(
        self,
        *,
        host: str = DEFAULT_HOST,
        credentials: ga_credentials.Credentials = None,
        credentials_file: Optional[str] = None,
        scopes: Optional[Sequence[str]] = None,
        quota_project_id: Optional[str] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
        always_use_jwt_access: Optional[bool] = False,
        api_audience: Optional[str] = None,
        **kwargs,
    ) -> None:
        """Instantiate the transport.

        Args:
            host (Optional[str]):
                 The hostname to connect to.
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is mutually exclusive with credentials.
            scopes (Optional[Sequence[str]]): A list of scopes.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                be used for service account credentials.
        """

        scopes_kwargs = {"scopes": scopes, "default_scopes": self.AUTH_SCOPES}

        # Save the scopes.
        self._scopes = scopes

        # If no credentials are provided, then determine the appropriate
        # defaults.
        if credentials and credentials_file:
            raise core_exceptions.DuplicateCredentialArgs(
                "'credentials_file' and 'credentials' are mutually exclusive"
            )

        if credentials_file is not None:
            credentials, _ = google.auth.load_credentials_from_file(
                credentials_file, **scopes_kwargs, quota_project_id=quota_project_id
            )
        elif credentials is None:
            credentials, _ = google.auth.default(
                **scopes_kwargs, quota_project_id=quota_project_id
            )
            # Don't apply audience if the credentials file passed from user.
            if hasattr(credentials, "with_gdch_audience"):
                credentials = credentials.with_gdch_audience(
                    api_audience if api_audience else host
                )

        # If the credentials are service account credentials, then always try to use self signed JWT.
        if (
            always_use_jwt_access
            and isinstance(credentials, service_account.Credentials)
            and hasattr(service_account.Credentials, "with_always_use_jwt_access")
        ):
            credentials = credentials.with_always_use_jwt_access(True)

        # Save the credentials.
        self._credentials = credentials

        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
        if ":" not in host:
            host += ":443"
        self._host = host

    def _prep_wrapped_messages(self, client_info):
        # Precompute the wrapped methods.
        self._wrapped_methods = {
            self.list_data_exchanges: gapic_v1.method.wrap_method(
                self.list_data_exchanges,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_org_data_exchanges: gapic_v1.method.wrap_method(
                self.list_org_data_exchanges,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_data_exchange: gapic_v1.method.wrap_method(
                self.get_data_exchange,
                default_timeout=None,
                client_info=client_info,
            ),
            self.create_data_exchange: gapic_v1.method.wrap_method(
                self.create_data_exchange,
                default_timeout=None,
                client_info=client_info,
            ),
            self.update_data_exchange: gapic_v1.method.wrap_method(
                self.update_data_exchange,
                default_timeout=None,
                client_info=client_info,
            ),
            self.delete_data_exchange: gapic_v1.method.wrap_method(
                self.delete_data_exchange,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_listings: gapic_v1.method.wrap_method(
                self.list_listings,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_listing: gapic_v1.method.wrap_method(
                self.get_listing,
                default_timeout=None,
                client_info=client_info,
            ),
            self.create_listing: gapic_v1.method.wrap_method(
                self.create_listing,
                default_timeout=None,
                client_info=client_info,
            ),
            self.update_listing: gapic_v1.method.wrap_method(
                self.update_listing,
                default_timeout=None,
                client_info=client_info,
            ),
            self.delete_listing: gapic_v1.method.wrap_method(
                self.delete_listing,
                default_timeout=None,
                client_info=client_info,
            ),
            self.subscribe_listing: gapic_v1.method.wrap_method(
                self.subscribe_listing,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_iam_policy: gapic_v1.method.wrap_method(
                self.get_iam_policy,
                default_timeout=None,
                client_info=client_info,
            ),
            self.set_iam_policy: gapic_v1.method.wrap_method(
                self.set_iam_policy,
                default_timeout=None,
                client_info=client_info,
            ),
            self.test_iam_permissions: gapic_v1.method.wrap_method(
                self.test_iam_permissions,
                default_timeout=None,
                client_info=client_info,
            ),
        }

    def close(self):
        """Closes resources associated with the transport.

        .. warning::
             Only call this method if the transport is NOT shared
             with other clients - this may cause errors in other clients!
        """
        raise NotImplementedError()

    @property
    def list_data_exchanges(
        self,
    ) -> Callable[
        [dataexchange.ListDataExchangesRequest],
        Union[
            dataexchange.ListDataExchangesResponse,
            Awaitable[dataexchange.ListDataExchangesResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def list_org_data_exchanges(
        self,
    ) -> Callable[
        [dataexchange.ListOrgDataExchangesRequest],
        Union[
            dataexchange.ListOrgDataExchangesResponse,
            Awaitable[dataexchange.ListOrgDataExchangesResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_data_exchange(
        self,
    ) -> Callable[
        [dataexchange.GetDataExchangeRequest],
        Union[dataexchange.DataExchange, Awaitable[dataexchange.DataExchange]],
    ]:
        raise NotImplementedError()

    @property
    def create_data_exchange(
        self,
    ) -> Callable[
        [dataexchange.CreateDataExchangeRequest],
        Union[dataexchange.DataExchange, Awaitable[dataexchange.DataExchange]],
    ]:
        raise NotImplementedError()

    @property
    def update_data_exchange(
        self,
    ) -> Callable[
        [dataexchange.UpdateDataExchangeRequest],
        Union[dataexchange.DataExchange, Awaitable[dataexchange.DataExchange]],
    ]:
        raise NotImplementedError()

    @property
    def delete_data_exchange(
        self,
    ) -> Callable[
        [dataexchange.DeleteDataExchangeRequest],
        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
    ]:
        raise NotImplementedError()

    @property
    def list_listings(
        self,
    ) -> Callable[
        [dataexchange.ListListingsRequest],
        Union[
            dataexchange.ListListingsResponse,
            Awaitable[dataexchange.ListListingsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_listing(
        self,
    ) -> Callable[
        [dataexchange.GetListingRequest],
        Union[dataexchange.Listing, Awaitable[dataexchange.Listing]],
    ]:
        raise NotImplementedError()

    @property
    def create_listing(
        self,
    ) -> Callable[
        [dataexchange.CreateListingRequest],
        Union[dataexchange.Listing, Awaitable[dataexchange.Listing]],
    ]:
        raise NotImplementedError()

    @property
    def update_listing(
        self,
    ) -> Callable[
        [dataexchange.UpdateListingRequest],
        Union[dataexchange.Listing, Awaitable[dataexchange.Listing]],
    ]:
        raise NotImplementedError()

    @property
    def delete_listing(
        self,
    ) -> Callable[
        [dataexchange.DeleteListingRequest],
        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
    ]:
        raise NotImplementedError()

    @property
    def subscribe_listing(
        self,
    ) -> Callable[
        [dataexchange.SubscribeListingRequest],
        Union[
            dataexchange.SubscribeListingResponse,
            Awaitable[dataexchange.SubscribeListingResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_iam_policy(
        self,
    ) -> Callable[
        [iam_policy_pb2.GetIamPolicyRequest],
        Union[policy_pb2.Policy, Awaitable[policy_pb2.Policy]],
    ]:
        raise NotImplementedError()

    @property
    def set_iam_policy(
        self,
    ) -> Callable[
        [iam_policy_pb2.SetIamPolicyRequest],
        Union[policy_pb2.Policy, Awaitable[policy_pb2.Policy]],
    ]:
        raise NotImplementedError()

    @property
    def test_iam_permissions(
        self,
    ) -> Callable[
        [iam_policy_pb2.TestIamPermissionsRequest],
        Union[
            iam_policy_pb2.TestIamPermissionsResponse,
            Awaitable[iam_policy_pb2.TestIamPermissionsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_location(
        self,
    ) -> Callable[
        [locations_pb2.GetLocationRequest],
        Union[locations_pb2.Location, Awaitable[locations_pb2.Location]],
    ]:
        raise NotImplementedError()

    @property
    def list_locations(
        self,
    ) -> Callable[
        [locations_pb2.ListLocationsRequest],
        Union[
            locations_pb2.ListLocationsResponse,
            Awaitable[locations_pb2.ListLocationsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def kind(self) -> str:
        raise NotImplementedError()


__all__ = ("AnalyticsHubServiceTransport",)
